import React, { useState } from 'react';
import classNames from 'classnames';
import Button from '../button';

function _empty() {}

function _awaitIgnored(value, direct) {
  if (!direct) {
    return value && value.then ? value.then(_empty) : Promise.resolve();
  }
}

function _await(value, then, direct) {
  if (direct) {
    return then ? then(value) : value;
  }

  if (!value || !value.then) {
    value = Promise.resolve(value);
  }

  return then ? value.then(then) : value;
}

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }

  if (result && result.then) {
    return result.then(void 0, recover);
  }

  return result;
}

function _continue(value, then) {
  return value && value.then ? value.then(then) : then(value);
}

function _async(f) {
  return function () {
    for (var args = [], i = 0; i < arguments.length; i++) {
      args[i] = arguments[i];
    }

    try {
      return Promise.resolve(f.apply(this, args));
    } catch (e) {
      return Promise.reject(e);
    }
  };
}

export var DialogActionButton = function DialogActionButton(props) {
  var action = props.action;

  var _useState = useState(false),
      loading = _useState[0],
      setLoading = _useState[1];

  return /*#__PURE__*/React.createElement(Button, {
    key: action.key,
    onClick: _async(function () {
      var _exit = false;
      setLoading(true);
      return _continue(_catch(function () {
        return _await(action.onClick == null ? void 0 : action.onClick(), function () {
          return _awaitIgnored(props.onAction == null ? void 0 : props.onAction());
        });
      }, function (e) {
        setLoading(false);
        throw e;
      }), function (_result) {
        if (_exit) return _result;
        setLoading(false);
      });
    }),
    className: classNames('am-dialog-button', {
      'am-dialog-button-bold': action.bold
    }),
    fill: 'none',
    block: true,
    color: action.danger ? 'danger' : 'primary',
    loading: loading,
    disabled: action.disabled
  }, action.text);
};